============
Introduction
============

These pages describe a git_ and github_ workflow for the NumPy_
project.

There are several different workflows here, for different ways of
working with *NumPy*.

This is not a comprehensive git_ reference, it's just a workflow for our
own project.  It's tailored to the github_ hosting service. You may well
find better or quicker ways of getting stuff done with git_, but these
should get you started.

For general resources for learning git_ see :ref:`git-resources`.

.. _install-git:

Install git
===========

Overview
--------

================ =============
Debian / Ubuntu  ``sudo apt-get install git-core``
Fedora           ``sudo yum install git-core``
Windows          Download and install msysGit_
OS X             Use the git-osx-installer_
================ =============

In detail
---------

See the git_ page for the most recent information.

Have a look at the github_ install help pages available from `github help`_

There are good instructions here: http://book.git-scm.com/2_installing_git.html

.. include:: git_links.inc
